@@ -9,8 +9,6 @@
 [![PyPI version](https://badge.fury.io/py/cdk-stepfunctions-patterns.svg)](https://badge.fury.io/py/cdk-stepfunctions-patterns)
 [![NuGet version](https://badge.fury.io/nu/Talnakh.StepFunctions.Patterns.svg)](https://badge.fury.io/nu/Talnakh.StepFunctions.Patterns)
 
-A simple CDK seeder for SQL Server RDS databases.
-
 *cdk-stepfunctions-patterns* library is a set of [AWS CDK](https://aws.amazon.com/cdk/) constructs that provide
 resiliency patterns implementation for AWS Step Functions.
 """
@@ -119,18 +117,14 @@ class ResilientLambdaTask(
         *,
         lambda_function: aws_cdk.aws_lambda.IFunction,
         client_context: typing.Optional[str] = None,
-        invocation_type: typing.Optional[
-            aws_cdk.aws_stepfunctions_tasks.LambdaInvocationType
-        ] = None,
+        invocation_type: typing.Optional[aws_cdk.aws_stepfunctions_tasks.LambdaInvocationType] = None,
         payload: typing.Optional[aws_cdk.aws_stepfunctions.TaskInput] = None,
         payload_response_only: typing.Optional[bool] = None,
         qualifier: typing.Optional[str] = None,
         comment: typing.Optional[str] = None,
         heartbeat: typing.Optional[aws_cdk.core.Duration] = None,
         input_path: typing.Optional[str] = None,
-        integration_pattern: typing.Optional[
-            aws_cdk.aws_stepfunctions.IntegrationPattern
-        ] = None,
+        integration_pattern: typing.Optional[aws_cdk.aws_stepfunctions.IntegrationPattern] = None,
         output_path: typing.Optional[str] = None,
         result_path: typing.Optional[str] = None,
         timeout: typing.Optional[aws_cdk.core.Duration] = None,
